summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMaciej Żenczykowski <maze@google.com>2020-04-18 00:32:21 +0000
committerMaciej Zenczykowski <maze@google.com>2020-04-18 00:38:19 +0000
commit1eec982530cab01a26092fd233ef57aa4c27864f (patch)
tree1a1dd6515f5bb910ba2dcfc482a5f735bf1abb80
parent4103490f6f1e9c72ca3b75f024983385f43bcbf0 (diff)
downloadtests-1eec982530cab01a26092fd233ef57aa4c27864f.tar.gz
net-test: buster -> bullseye
as aosp master has upgraded to iptables 1.8.4 and buster image simply doesn't build any more... (there is no debian 1.8.4 for buster [stable], but there is for bullseye [testing]) Tested: known to not work, see followup commit find | egrep buster git grep buster (finds nothing) Bug: 143044679 Signed-off-by: Maciej Żenczykowski <maze@google.com> Change-Id: I01b973367354e12d237f53b593b768fdcb4fde54 Merged-In: I01b973367354e12d237f53b593b768fdcb4fde54
-rwxr-xr-xnet/test/build_all_rootfs.sh2
-rwxr-xr-xnet/test/build_rootfs.sh6
-rw-r--r--net/test/rootfs/bullseye.list (renamed from net/test/rootfs/buster.list)0
-rwxr-xr-xnet/test/rootfs/bullseye.sh (renamed from net/test/rootfs/buster.sh)6
4 files changed, 7 insertions, 7 deletions
diff --git a/net/test/build_all_rootfs.sh b/net/test/build_all_rootfs.sh
index 8cdc2be..6e4fdd6 100755
--- a/net/test/build_all_rootfs.sh
+++ b/net/test/build_all_rootfs.sh
@@ -17,7 +17,7 @@
set -e
-for s in buster; do
+for s in bullseye; do
for a in i386 amd64 armhf arm64; do
./build_rootfs.sh -s "${s}" -a "${a}"
done
diff --git a/net/test/build_rootfs.sh b/net/test/build_rootfs.sh
index 2f58a89..d31674d 100755
--- a/net/test/build_rootfs.sh
+++ b/net/test/build_rootfs.sh
@@ -27,14 +27,14 @@ unset LANG LANGUAGE \
export LC_ALL=C
usage() {
- echo -n "usage: $0 [-h] [-s buster] [-a i386|amd64|armhf|arm64] "
+ echo -n "usage: $0 [-h] [-s bullseye] [-a i386|amd64|armhf|arm64] "
echo "[-m http://mirror/debian] [-n net_test.rootfs.`date +%Y%m%d`]"
exit 1
}
mirror=http://ftp.debian.org/debian
debootstrap=debootstrap
-suite=buster
+suite=bullseye
arch=amd64
while getopts ":hs:a:m:n:" opt; do
@@ -43,7 +43,7 @@ while getopts ":hs:a:m:n:" opt; do
usage
;;
s)
- if [[ "$OPTARG" != "buster" ]]; then
+ if [[ "$OPTARG" != "bullseye" ]]; then
echo "Invalid suite: $OPTARG" >&2
usage
fi
diff --git a/net/test/rootfs/buster.list b/net/test/rootfs/bullseye.list
index fbeddde..fbeddde 100644
--- a/net/test/rootfs/buster.list
+++ b/net/test/rootfs/bullseye.list
diff --git a/net/test/rootfs/buster.sh b/net/test/rootfs/bullseye.sh
index 56b2276..9fde44e 100755
--- a/net/test/rootfs/buster.sh
+++ b/net/test/rootfs/bullseye.sh
@@ -27,8 +27,8 @@ cd /root
# Add the needed debian sources
cat >/etc/apt/sources.list <<EOF
-deb http://ftp.debian.org/debian buster main
-deb-src http://ftp.debian.org/debian buster main
+deb http://ftp.debian.org/debian bullseye main
+deb-src http://ftp.debian.org/debian bullseye main
EOF
# Disable the automatic installation of recommended packages
@@ -42,7 +42,7 @@ apt-get update
# Note what we have installed; we will go back to this
LANG=C dpkg --get-selections | sort >originally-installed
# Install everything needed from buster to build iptables
apt-get install -y \
build-essential \
autoconf \
@@ -42,7 +42,7 @@ apt-get update
# Note what we have installed; we will go back to this
LANG=C dpkg --get-selections | sort >originally-installed
-# Install everything needed from buster to build iptables
+# Install everything needed from bullseye to build iptables
apt-get install -y \
build-essential \